@@ -1,4 +1,4 @@
-#define NGX_CONFIGURE " --with-cc=x86_64-pc-linux-gnu-gcc --with-cpp='x86_64-pc-linux-gnu-gcc -E' --with-ld-opt='-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs' --builddir=build --prefix=/usr/lib64/nginx --sbin-path=/usr/sbin/nginx --modules-path=/usr/lib64/nginx/modules --conf-path=/etc/nginx/nginx.conf --error-log-path=/var/log/nginx/error.log --http-log-path=/var/log/nginx/access.log --pid-path=/run/nginx/nginx.pid --lock-path=/run/lock/nginx.lock --user=nginx --group=nginx --with-threads --with-compat --http-client-body-temp-path=/var/cache/nginx/client_body_temp --http-proxy-temp-path=/var/cache/nginx/proxy_temp --http-fastcgi-temp-path=/var/cache/nginx/fastcgi_temp --http-uwsgi-temp-path=/var/cache/nginx/uwsgi_temp --http-scgi-temp-path=/var/cache/nginx/scgi_temp --with-http_ssl_module --with-mail_ssl_module --with-stream_ssl_module"
+#define NGX_CONFIGURE " --with-cc=x86_64-pc-linux-gnu-gcc --with-cpp='x86_64-pc-linux-gnu-gcc -E' --with-ld-opt='-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs' --builddir=build --prefix=/usr/lib64/nginx --sbin-path=/usr/sbin/nginx --modules-path=/usr/lib64/nginx/modules --conf-path=/etc/nginx/nginx.conf --error-log-path=/var/log/nginx/error.log --http-log-path=/var/log/nginx/access.log --pid-path=/run/nginx/nginx.pid --lock-path=/run/lock/nginx.lock --user=nginx --group=nginx --with-threads --with-compat --http-client-body-temp-path=/var/cache/nginx/client_body_temp --http-proxy-temp-path=/var/cache/nginx/proxy_temp --http-fastcgi-temp-path=/var/cache/nginx/fastcgi_temp --http-uwsgi-temp-path=/var/cache/nginx/uwsgi_temp --http-scgi-temp-path=/var/cache/nginx/scgi_temp --with-http_ssl_module --with-http_v2_module --with-mail_ssl_module --with-stream_ssl_module"
 
 #ifndef NGX_COMPILER
 #define NGX_COMPILER  "gcc 15.2.1 20251122 (Gentoo Hardened 15.2.1_p20251122 p3) "
@@ -410,6 +410,11 @@
 #endif
 
 
+#ifndef NGX_HTTP_V2
+#define NGX_HTTP_V2  1
+#endif
+
+
 #ifndef NGX_CRYPT
 #define NGX_CRYPT  1
 #endif
